@@ -39,6 +39,9 @@ pub struct Options {
     /// Add `#[serde(with = "serde_bytes")]` to the provided column.
     #[structopt(short = "B")]
     pub bytes: Vec<String>,
+    /// Ignore a specified column.
+    #[structopt(short = "I", number_of_values = 1)]
+    pub ignore: Vec<String>,
 }
 
 #[derive(Debug, PartialEq, Eq, PartialOrd, Ord)]
@@ -50,7 +53,7 @@ pub struct Type {
 fn parse_type(s: &str) -> Result<Type> {
     let (sql, type_) = s.split_once('=').context("invalid key-value")?;
     Ok(Type {
-        sql: crate::miner::parse_type(&sql)?,
+        sql: crate::miner::parse_type(sql)?,
         type_: type_.into(),
     })
 }
@@ -117,6 +120,14 @@ impl Options {
             let _ = writeln!(&mut s, "    -B '{}' \\", b);
         }
 
+        // -I
+        let mut ignore = self.ignore.iter().collect::<Vec<_>>();
+        ignore.sort();
+
+        for i in ignore {
+            let _ = writeln!(&mut s, "    -I '{}' \\", i);
+        }
+
         s.trim_end_matches(|c| c == '\\' || c == ' ' || c == '\n')
             .into()
     }
